########
 Teamux
########

**Teamux**

Tmux wrapper

========
Abstract
========

Tmux Python library

=====
Usage
=====

Python:
.. code-block:: python

   from teamux import tmux

============
Installation
============

.. code-block:: shell 

    $ pip install teamux
